package IOD;

our $DATE = '2014-08-28'; # DATE
our $VERSION = '0.9.6'; # VERSION

1;
# ABSTRACT: IOD (INI On Drugs) file format specification

__END__

=pod

=encoding UTF-8

=head1 NAME

IOD - IOD (INI On Drugs) file format specification

=head1 VERSION

This document describes version 0.9.6 of IOD (from Perl distribution IOD), released on 2014-08-28.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/IOD>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-IOD>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=IOD>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
